#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_FLOOR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_FLOOR_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/scalar/floor.hpp>

#endif
